---
name: Issue
about: Use this template for all issues.
title: ''
labels: ''
assignees: ''
---
* gevent version: Please note how you installed it: From source, from
                  PyPI, from your operating system's package, etc.
* Python version: Please be as specific as possible. For example,
                  "cPython 2.7.9 downloaded from python.org"
* Operating System: Please be as specific as possible. For example,
                  "Raspbian (Debian Linux 8.0 Linux 4.9.35-v7+  armv7l)"

### Description:

**REPLACE ME**: What are you trying to get done, what has happened, what went wrong, and what did you expect?

**IMPORTANT**: Please DO NOT POST SCREENSHOTS OF TEXT. Copy and paste
the actual text. This means: No screenshots of your editor. No
screenshots of tracebacks or console output.

```python-traceback
Remember to put tracebacks in literal blocks
```

### What I've run:

**REPLACE ME**: Paste short, self contained, correct example code (See
http://sscce.org), tracebacks, etc, here


```python
"Put python code in python blocks"
```
